pub struct KeyUpEvent {
pub code: ScanCode,
pub key: String,
pub shift: bool,
pub alt: bool,
pub ctrl: bool,
}Expand description
data associated with a key release event
Possible values for the virtual key code can be found in unrust/uni-app’s translate_scan_code
function.
Warning, there are some slight variations from one OS to another, for example the Command, F13, F14, F15 keys
only exist on Mac.
Fields
code: ScanCodescancode : top left letter is ScanCode::Q even on an azerty keyboard
key: Stringvirtual key code : top left letter is “KeyQ” on qwerty, “KeyA” on azerty
shift: boolwhether a shift key is pressed
alt: boolwhether an alt key is pressed
ctrl: boolwhether a control key is pressed